@@ -4,5 +4,8 @@
 # Configuration- and function files used by the test harness
 configfile = 'tests/selftest.ini'
 configfile_v2 = 'tests/selftest_v2.ini'
+configfile_no_functions = 'tests/etc/no-functions.ini'
+configfile_empty_functions = 'tests/etc/empty-functions.ini'
+configfile_bad_functions = 'tests/etc/bad-functions.ini'
 funcfile = 'tests/selftest.py'
 bad_funcfile = 'tests/bad_funcs.py'
